using System;
using System.Drawing;
using System.Windows.Forms;

namespace SDK.Sample
{
	/// <summary>
	/// Summary description for FormattedText.
	/// </summary>
	public class FormattedText : TextBox
	{
		private String mDateString;
		private String mFormatString;
		private Color mEditModeColor;
		private Color mNonEditModeColor;
	   
		public FormattedText()
		{
			this.mDateString = DateTime.Now.ToString();
			this.Text = this.mDateString;
			//http://msdn2.microsoft.com/en-us/library/zdtaw1bw.aspx
			this.mFormatString = "U";
			this.mEditModeColor = Color.White;
			this.mNonEditModeColor = Color.LightGray;
			this.BackColor =  Color.LightGray;
			
		}

		/// <summary>
		/// 
		/// </summary>
		/// <param name="UnformattedString"></param>
		/// <param name="mFormatString"></param>
		public FormattedText(String FormatString) 
		{
			this.mDateString = DateTime.Now.ToString();
			this.Text = this.mDateString;
			//http://msdn2.microsoft.com/en-us/library/zdtaw1bw.aspx
			this.mFormatString = FormatString;
			this.mEditModeColor = Color.White;
			this.mNonEditModeColor = Color.LightGray;
			this.BackColor =  Color.LightGray;
		}

		/// <summary>
		/// 
		/// </summary>
		/// <param name="e"></param>
		protected override void OnTextChanged(EventArgs e)
		{
			if (this.BackColor == this.mNonEditModeColor)
			{
				DateTime dateTime = DateTime.Parse(this.mDateString);
				this.Text = dateTime.ToString(this.mFormatString);
				base.OnTextChanged (e);
			}			
		}

		/// <summary>
		/// 
		/// </summary>
		/// <param name="e"></param>
		protected override void OnLeave(EventArgs e)
		{
			if (this.BackColor == this.mEditModeColor) 
			{
				try 
				{
					DateTime dateTime = DateTime.Parse(this.Text);
					this.mDateString = this.Text;
					this.Text = dateTime.ToString(this.mFormatString);
				}
				catch
				{
					DateTime dateTime = DateTime.Parse(this.mDateString);
					this.Text = dateTime.ToString(this.mFormatString);
				}				
				this.BackColor =  this.mNonEditModeColor;
			}
			base.OnLeave (e);
		}

		/// <summary>
		/// 
		/// </summary>
		/// <param name="e"></param>
		protected override void OnClick(EventArgs e)
		{
			if (this.BackColor == this.mNonEditModeColor) 
			{
				this.BackColor = this.mEditModeColor;
				this.Text = this.mDateString;
			}
			base.OnClick (e);
		}

		/// <summary>
		/// 
		/// </summary>
		public String DateString
		{
			get
			{
				return( mDateString );
			}

			set
			{
				mDateString = value;
			}
		}

		/// <summary>
		/// 
		/// </summary>
		public String FormatString
		{
			get
			{
				return( mFormatString );
			}

			set
			{
				mFormatString = value;
			}
		}

		/// <summary>
		/// 
		/// </summary>
		public Color EditModeColor
		{
			get
			{
				return( mEditModeColor );
			}

			set
			{
				mEditModeColor = value;
			}
		}

		/// <summary>
		/// 
		/// </summary>
		public Color NonEditModeColor
		{
			get
			{
				return( mNonEditModeColor );
			}

			set
			{
				mNonEditModeColor = value;
			}
		}

	}
}
